@@ -3,4 +3,7 @@
 # SPDX-License-Identifier: AGPL-3.0-only
 """Python tools for Updater and repository maintenance."""
 
-from univention.updater.tools import UniventionUpdater  # noqa: F401
+from univention.updater.tools import UniventionUpdater
+
+
+__all__ = ('UniventionUpdater',)
